@@ -23,15 +23,16 @@ test_that("Radial-Egger using default prior method",
                              yse = dodata$chdse)
 
             radialeggerfit <- mr_radialegger_rjags(dat,
-                                                   seed = c(123, 456, 789))
+                                                   seed = c(123, 456, 789),
+                                                   sigmaprior = "dunif(1,10)")
             expect_equal(class(radialeggerfit), "radialeggerjags")
             expect_equal(unname(radialeggerfit$CausalEffect), 0.591, tol = 1e-2)
-            expect_equal(unname(radialeggerfit$StandardError), 0.078, tol = 1e-2)
-            expect_equal(unname(radialeggerfit$CredibleInterval[1]), 0.438, tol = 1e-2)
+            expect_equal(unname(radialeggerfit$StandardError), 0.051, tol = 1e-2)
+            expect_equal(unname(radialeggerfit$CredibleInterval[1]), 0.494, tol = 1e-2)
             expect_equal(unname(radialeggerfit$CredibleInterval[2]), 0.591, tol = 1e-2)
-            expect_equal(unname(radialeggerfit$CredibleInterval[3]), 0.746, tol = 1e-2)
-            expect_equal(unname(radialeggerfit$AvgPleio), -0.252, tol = 1e-2 )
-            expect_equal(unname(radialeggerfit$sigma), 0.404, tol = 1e-2)
+            expect_equal(unname(radialeggerfit$CredibleInterval[3]), 0.692, tol = 1e-2)
+            expect_equal(unname(radialeggerfit$AvgPleio), -0.252, tol = 1e-2)
+            expect_equal(unname(radialeggerfit$sigma), 1.01, tol = 1e-2)
             expect_equal(class(radialeggerfit$samples), "mcmc.list")
             expect_equal(radialeggerfit$priormethod, "default")
           })
@@ -48,15 +49,16 @@ test_that("Radial-Egger using weak prior method",
 
             radialeggerfit1 <- mr_radialegger_rjags(dat,
                                                     prior = "weak",
-                                                    seed = c(123, 456, 789))
+                                                    seed = c(123, 456, 789),
+                                                    sigmaprior = "dunif(1,10)")
             expect_equal(class(radialeggerfit1), "radialeggerjags")
             expect_equal(unname(radialeggerfit1$CausalEffect), 0.591, tol = 1e-2)
-            expect_equal(unname(radialeggerfit1$StandardError), 0.0788, tol = 1e-2)
-            expect_equal(unname(radialeggerfit1$CredibleInterval[1]),0.438 , tol = 1e-2)
+            expect_equal(unname(radialeggerfit1$StandardError), 0.0507, tol = 1e-2)
+            expect_equal(unname(radialeggerfit1$CredibleInterval[1]), 0.494, tol = 1e-2)
             expect_equal(unname(radialeggerfit1$CredibleInterval[2]), 0.591, tol = 1e-2)
-            expect_equal(unname(radialeggerfit1$CredibleInterval[3]), 0.746, tol = 1e-2)
-            expect_equal(unname(radialeggerfit1$AvgPleio), -0.252, tol = 1e-2 )
-            expect_equal(unname(radialeggerfit1$sigma), 0.404, tol = 1e-2)
+            expect_equal(unname(radialeggerfit1$CredibleInterval[3]), 0.692, tol = 1e-2)
+            expect_equal(unname(radialeggerfit1$AvgPleio), -0.252, tol = 1e-2)
+            expect_equal(unname(radialeggerfit1$sigma), 1.01, tol = 1e-2)
             expect_equal(class(radialeggerfit1$samples), "mcmc.list")
             expect_equal(radialeggerfit1$priormethod, "weak")
           })
@@ -73,15 +75,16 @@ test_that("Radial-Egger using pseudo prior method",
 
             radialeggerfit2 <- mr_radialegger_rjags(dat,
                                                     prior = "pseudo",
-                                                    seed = c(123, 456, 789))
+                                                    seed = c(123, 456, 789),
+                                                    sigmaprior = "dunif(1,10)")
             expect_equal(class(radialeggerfit2), "radialeggerjags")
             expect_equal(unname(radialeggerfit2$CausalEffect), 0.586, tol = 1e-2)
-            expect_equal(unname(radialeggerfit2$StandardError), 0.0795, tol = 1e-2)
-            expect_equal(unname(radialeggerfit2$CredibleInterval[1]), 0.426, tol = 1e-2)
+            expect_equal(unname(radialeggerfit2$StandardError), 0.0507, tol = 1e-2)
+            expect_equal(unname(radialeggerfit2$CredibleInterval[1]), 0.494, tol = 1e-2)
             expect_equal(unname(radialeggerfit2$CredibleInterval[2]), 0.586, tol = 1e-2)
-            expect_equal(unname(radialeggerfit2$CredibleInterval[3]), 0.739, tol = 1e-2)
-            expect_equal(unname(radialeggerfit2$AvgPleio), -0.245, tol = 1e-2 )
-            expect_equal(unname(radialeggerfit2$sigma), 0.404, tol = 1e-2)
+            expect_equal(unname(radialeggerfit2$CredibleInterval[3]), 0.692, tol = 1e-2)
+            expect_equal(unname(radialeggerfit2$AvgPleio), -0.245, tol = 1e-2)
+            expect_equal(unname(radialeggerfit2$sigma), 1.01, tol = 1e-2)
             expect_equal(class(radialeggerfit2$samples), "mcmc.list")
             expect_equal(radialeggerfit2$priormethod, "pseudo")
           })
@@ -99,15 +102,16 @@ test_that("Radial-Egger using joint prior method",
             radialeggerfit3 <- mr_radialegger_rjags(dat,
                                                     prior = "joint",
                                                     seed = c(123, 456, 789),
-                                                    rho = 0.5)
+                                                    rho = 0.5,
+                                                    sigmaprior = "dunif(1,10)")
             expect_equal(class(radialeggerfit3), "radialeggerjags")
             expect_equal(unname(radialeggerfit3$CausalEffect), 0.588, tol = 1e-2)
-            expect_equal(unname(radialeggerfit3$StandardError), 0.0797, tol = 1e-2)
-            expect_equal(unname(radialeggerfit3$CredibleInterval[1]), 0.434, tol = 1e-2)
-            expect_equal(unname(radialeggerfit3$CredibleInterval[2]), 0.588, tol = 1e-2)
-            expect_equal(unname(radialeggerfit3$CredibleInterval[3]), 0.745, tol = 1e-2)
-            expect_equal(unname(radialeggerfit3$AvgPleio), -0.241, tol = 1e-2 )
-            expect_equal(unname(radialeggerfit3$sigma), 0.406, tol = 1e-2)
+            expect_equal(unname(radialeggerfit3$StandardError), 0.0507, tol = 1e-2)
+            expect_equal(unname(radialeggerfit3$CredibleInterval[1]), 0.494, tol = 1e-2)
+            expect_equal(unname(radialeggerfit3$CredibleInterval[2]), 0.591, tol = 1e-2)
+            expect_equal(unname(radialeggerfit3$CredibleInterval[3]), 0.692, tol = 1e-2)
+            expect_equal(unname(radialeggerfit3$AvgPleio), -0.253, tol = 1e-2)
+            expect_equal(unname(radialeggerfit3$sigma), 1.01, tol = 1e-2)
             expect_equal(class(radialeggerfit3$samples), "mcmc.list")
             expect_equal(radialeggerfit3$priormethod, "joint")
           })
@@ -124,15 +128,15 @@ test_that("Radial-Egger using betaprior and sigmaprior method",
 
             radialeggerfit4 <- mr_radialegger_rjags(dat,
                                                     betaprior = "dnorm(0, 1E-6)",
-                                                    sigmaprior = "dunif(.0001, 10)",
+                                                    sigmaprior = "dunif(1, 10)",
                                                     seed = c(123, 456, 789))
             expect_equal(class(radialeggerfit4), "radialeggerjags")
             expect_equal(unname(radialeggerfit4$CausalEffect), 0.591, tol = 1e-2)
-            expect_equal(unname(radialeggerfit4$StandardError), 0.078, tol = 1e-2)
-            expect_equal(unname(radialeggerfit4$CredibleInterval[1]),0.438 , tol = 1e-2)
+            expect_equal(unname(radialeggerfit4$StandardError), 0.0507, tol = 1e-2)
+            expect_equal(unname(radialeggerfit4$CredibleInterval[1]), 0.494, tol = 1e-2)
             expect_equal(unname(radialeggerfit4$CredibleInterval[2]), 0.591, tol = 1e-2)
-            expect_equal(unname(radialeggerfit4$CredibleInterval[3]), 0.746, tol = 1e-2)
-            expect_equal(unname(radialeggerfit4$AvgPleio), -0.252, tol = 1e-2 )
-            expect_equal(unname(radialeggerfit4$sigma), 0.404, tol = 1e-2)
+            expect_equal(unname(radialeggerfit4$CredibleInterval[3]), 0.692, tol = 1e-2)
+            expect_equal(unname(radialeggerfit4$AvgPleio), -0.252, tol = 1e-2)
+            expect_equal(unname(radialeggerfit4$sigma), 1.01, tol = 1e-2)
             expect_equal(class(radialeggerfit4$samples), "mcmc.list")
           })
